==> styler_identity-0.4.0-py2.py3-none-any.whl: styler_identity/identity.py <==
# -*- coding: utf-8 -*-

""" Identity class

    Encapsulates the logic to handle JWT tokens
"""

import logging

from jwt.exceptions import InvalidTokenError
import jwt


class Identity:
    """ Holds the identity of the logged user
    """
    def __init__(self, token):
        self._token = token
        try:
            self._decoded = jwt.decode(self._token, verify=False)
        except InvalidTokenError:
            raise ValueError('Invalid JWT token')

    def user_id(self):
        """ Returns the user_id provided by firebase
        """
        return self._decoded.get('user_id')

    def is_system_admin(self):
        """ Returns a boolean identifying the user as system administrator
        """
        return self._decoded.get('system_admin', False)

    def shops(self):
        """ Returns a list of shop_ids that the user has access to
        """
        claims = self._decoded.get('claims')
        if not claims:
            logging.error('claims not found')
            return []
        return claims.get('shop', [])

    def organizations(self):
        """ Returns a list of organization_ids that the user has access to
        """
        claims = self._decoded.get('claims')
        if not claims:
            logging.error('claims not found')
            return []
        return claims.get('organization', [])

    def data(self):
        """ Return the entire data from the token
        """
        return self._decoded

    def token(self):
        """ Returns the original JWT token
        """
        return self._token

==> styler_identity-0.5.0-py2.py3-none-any.whl: styler_identity/identity.py <==
# -*- coding: utf-8 -*-

""" Identity class

    Encapsulates the logic to handle JWT tokens
"""

import logging

from jwt.exceptions import InvalidTokenError
import jwt


class Identity:
    """ Holds the identity of the logged user
    """
    def __init__(self, token):
        self._token = token
        try:
            self._decoded = jwt.decode(self._token, verify=False)
        except InvalidTokenError:
            raise ValueError('Invalid JWT token')

    def user_id(self):
        """ Returns the user_id provided by firebase
        """
        return self._decoded.get('user_id')

    def is_system_admin(self):
        """ Returns a boolean identifying the user as a system administrator
        """
        roles = self._decoded.get('roles')
        if not roles:
            logging.error('roles not found')
            return False
        return 'sysadmin' in roles

    def is_admin(self):
        """ Returns a boolean identifying the user 
            as an organization administrator
        """
        roles = self._decoded.get('roles')
        if not roles:
            logging.error('roles not found')
            return False
        return 'admin' in roles

    def is_staff(self):
        """ Returns a boolean identifying the user 
            as a shop staff
        """
        roles = self._decoded.get('roles')
        if not roles:
            logging.error('roles not found')
            return False
        return 'staff' in roles

    def shops(self):
        """ Returns a list of shop_ids that the user has access to
        """
        claims = self._decoded.get('claims')
        if not claims:
            logging.error('claims not found')
            return []
        return claims.get('shop', [])

    def organizations(self):
        """ Returns a list of organization_ids that the user has access to
        """
        claims = self._decoded.get('claims')
        if not claims:
            logging.error('claims not found')
            return []
        return claims.get('organization', [])

    def data(self):
        """ Return the entire data from the token
        """
        return self._decoded

    def token(self):
        """ Returns the original JWT token
        """
        return self._token
